@@ -733,6 +733,25 @@ class ImportExportService:
             source_session.close()
             mini_session.close()
 
+    def _convert_rapporti_to_mini_format(self, rapporti_str: str) -> str:
+        """
+        Convert PyArchInit rapporti format to PyArchInit-Mini format
+
+        PyArchInit: [['Copre', '3', '1', 'Scavo archeologico'], ['Copre', '11', '1', 'Scavo archeologico']]
+        PyArchInit-Mini: Copre 3, Copre 11
+        """
+        if not rapporti_str or rapporti_str == '[]':
+            return ''
+
+        try:
+            relationships = self._parse_pyarchinit_rapporti(rapporti_str)
+            # Format as "Relationship US, Relationship US, ..."
+            formatted = ', '.join([f"{rel_type} {us_num}" for rel_type, us_num in relationships])
+            return formatted
+        except Exception as e:
+            logger.warning(f"Failed to convert rapporti format: {rapporti_str} - {str(e)}")
+            return rapporti_str  # Return original if conversion fails
+
     def _map_us_fields_import(self, source_data: Dict[str, Any]) -> Dict[str, Any]:
         """Map US fields from PyArchInit to PyArchInit-Mini format"""
 
@@ -787,7 +806,7 @@ class ImportExportService:
             # Text fields
             'inclusi': source_data.get('inclusi'),
             'campioni': source_data.get('campioni'),
-            'rapporti': source_data.get('rapporti'),  # Copy rapporti field for compatibility
+            'rapporti': self._convert_rapporti_to_mini_format(source_data.get('rapporti', '')),  # Convert to readable format
             'documentazione': source_data.get('documentazione'),
             'cont_per': source_data.get('cont_per'),
 
@@ -1439,3 +1458,217 @@ class ImportExportService:
         except Exception as e:
             logger.error(f"Database validation failed: {str(e)}")
             return False
+
+    def sync_datazioni_from_periodizzazione(self) -> Dict[str, Any]:
+        """
+        Synchronize datazioni_table from unique periodo values in periodizzazione_table
+
+        This creates entries in datazioni_table for each unique periodo found in
+        periodizzazione, if they don't already exist.
+
+        Returns:
+            Dictionary with sync statistics
+        """
+        stats = {'created': 0, 'skipped': 0, 'errors': []}
+
+        mini_session = self.mini_session_maker()
+
+        try:
+            # Get unique periodo values from periodizzazione_table
+            result = mini_session.execute(text("""
+                SELECT DISTINCT periodo_iniziale, datazione_estesa
+                FROM periodizzazione_table
+                WHERE periodo_iniziale IS NOT NULL AND periodo_iniziale != ''
+                ORDER BY periodo_iniziale
+            """))
+
+            unique_periodi = result.fetchall()
+            logger.info(f"Found {len(unique_periodi)} unique periodi in periodizzazione")
+
+            for periodo_row in unique_periodi:
+                periodo_nome = periodo_row[0]
+                datazione_estesa = periodo_row[1] or ''
+
+                try:
+                    # Check if datazione already exists
+                    existing = mini_session.execute(
+                        text("SELECT id_datazione FROM datazioni_table WHERE nome_datazione = :nome"),
+                        {'nome': periodo_nome}
+                    ).fetchone()
+
+                    if not existing:
+                        # Insert new datazione
+                        mini_session.execute(text("""
+                            INSERT INTO datazioni_table (nome_datazione, descrizione, created_at, updated_at)
+                            VALUES (:nome, :descrizione, :created, :updated)
+                        """), {
+                            'nome': periodo_nome,
+                            'descrizione': datazione_estesa,
+                            'created': datetime.now(),
+                            'updated': datetime.now()
+                        })
+                        mini_session.commit()
+                        stats['created'] += 1
+                        logger.info(f"Created datazione: {periodo_nome}")
+                    else:
+                        stats['skipped'] += 1
+
+                except Exception as e:
+                    mini_session.rollback()
+                    error_msg = f"Error syncing datazione '{periodo_nome}': {str(e)}"
+                    logger.error(error_msg)
+                    stats['errors'].append(error_msg)
+
+            return stats
+
+        except Exception as e:
+            logger.error(f"Sync datazioni failed: {str(e)}")
+            raise
+        finally:
+            mini_session.close()
+
+    def sync_datazioni_from_us_values(self) -> Dict[str, Any]:
+        """
+        Synchronize datazioni_table from unique datazione values in us_table
+
+        This creates entries in datazioni_table for each unique datazione value
+        found in us_table, if they don't already exist. This ensures that all
+        datazione values from imported US records are available in the dropdown.
+
+        Returns:
+            Dictionary with sync statistics
+        """
+        stats = {'created': 0, 'skipped': 0, 'errors': []}
+
+        mini_session = self.mini_session_maker()
+
+        try:
+            # Get unique datazione values from us_table
+            result = mini_session.execute(text("""
+                SELECT DISTINCT datazione
+                FROM us_table
+                WHERE datazione IS NOT NULL AND datazione != ''
+                ORDER BY datazione
+            """))
+
+            unique_datazioni = result.fetchall()
+            logger.info(f"Found {len(unique_datazioni)} unique datazione values in us_table")
+
+            for datazione_row in unique_datazioni:
+                datazione_value = datazione_row[0]
+
+                try:
+                    # Check if datazione already exists
+                    existing = mini_session.execute(
+                        text("SELECT id_datazione FROM datazioni_table WHERE nome_datazione = :nome"),
+                        {'nome': datazione_value}
+                    ).fetchone()
+
+                    if not existing:
+                        # Insert new datazione
+                        mini_session.execute(text("""
+                            INSERT INTO datazioni_table (nome_datazione, descrizione, created_at, updated_at)
+                            VALUES (:nome, :descrizione, :created, :updated)
+                        """), {
+                            'nome': datazione_value,
+                            'descrizione': datazione_value,  # Use same value for description
+                            'created': datetime.now(),
+                            'updated': datetime.now()
+                        })
+                        mini_session.commit()
+                        stats['created'] += 1
+                        logger.info(f"Created datazione from US: {datazione_value}")
+                    else:
+                        stats['skipped'] += 1
+
+                except Exception as e:
+                    mini_session.rollback()
+                    error_msg = f"Error syncing datazione '{datazione_value}': {str(e)}"
+                    logger.error(error_msg)
+                    stats['errors'].append(error_msg)
+
+            return stats
+
+        except Exception as e:
+            logger.error(f"Sync datazioni from US failed: {str(e)}")
+            raise
+        finally:
+            mini_session.close()
+
+    def update_us_datazione_from_periodizzazione(self, sito_filter: Optional[List[str]] = None) -> Dict[str, Any]:
+        """
+        Update datazione field in us_table based on periodizzazione_table data
+
+        For each US, finds the corresponding periodo_iniziale from periodizzazione
+        and sets it as the datazione field in us_table.
+
+        Args:
+            sito_filter: List of site names to update (None = update all)
+
+        Returns:
+            Dictionary with update statistics
+        """
+        stats = {'updated': 0, 'skipped': 0, 'errors': []}
+
+        mini_session = self.mini_session_maker()
+
+        try:
+            # Build query for US with sito filter
+            us_query = "SELECT sito, us FROM us_table"
+            if sito_filter:
+                placeholders = ','.join([f"'{s}'" for s in sito_filter])
+                us_query += f" WHERE sito IN ({placeholders})"
+
+            result = mini_session.execute(text(us_query))
+            us_list = result.fetchall()
+
+            logger.info(f"Updating datazione for {len(us_list)} US from periodizzazione")
+
+            for us_row in us_list:
+                sito = us_row[0]
+                us_num = us_row[1]
+
+                try:
+                    # Get periodo_iniziale from periodizzazione for this US
+                    periodo_result = mini_session.execute(text("""
+                        SELECT periodo_iniziale
+                        FROM periodizzazione_table
+                        WHERE sito = :sito AND us = :us
+                        LIMIT 1
+                    """), {'sito': sito, 'us': us_num})
+
+                    periodo_row = periodo_result.fetchone()
+
+                    if periodo_row and periodo_row[0]:
+                        periodo_iniziale = periodo_row[0]
+
+                        # Update us_table datazione field
+                        mini_session.execute(text("""
+                            UPDATE us_table
+                            SET datazione = :datazione, updated_at = :updated
+                            WHERE sito = :sito AND us = :us
+                        """), {
+                            'datazione': periodo_iniziale,
+                            'updated': datetime.now(),
+                            'sito': sito,
+                            'us': us_num
+                        })
+                        mini_session.commit()
+                        stats['updated'] += 1
+                    else:
+                        stats['skipped'] += 1
+
+                except Exception as e:
+                    mini_session.rollback()
+                    error_msg = f"Error updating US {sito}/{us_num}: {str(e)}"
+                    logger.error(error_msg)
+                    stats['errors'].append(error_msg)
+
+            logger.info(f"Updated {stats['updated']} US with datazione from periodizzazione")
+            return stats
+
+        except Exception as e:
+            logger.error(f"Update US datazione failed: {str(e)}")
+            raise
+        finally:
+            mini_session.close()
